#!/bin/ksh
#set -x

##########################################
#
# Functions
#
##########################################

CheckEnv()
{
	# ensure that dataLoad.env is already sourced
	echo "Checking PROVISO environment ..."
	if [ ! $PVMHOME ]; then 
		UsageMsg
	fi

	if [ ! $ORACLE_HOME ]; then 
		UsageMsg
	fi


}

CheckOptions()
{
	DATABASE_PASSWORD="$1"
	if [ ! $DATABASE_PASSWORD ]; then 
		echo "  Warning, using default 'PV' as database password"
		DATABASE_PASSWORD="PV"; 
	fi

	COLL_REF_PORT="$2"
	if [ ! $COLL_REF_PORT ]; then 
		echo "  Warning, using default 3002 as collector port"
		COLL_REF_PORT="3002"; 
	fi

	DIRNAME=`dirname $0`
	if [ "$DIRNAME" = "." ]; then DIRNAME=`pwd`; fi

	NEWPVMHOME=`echo $DIRNAME | sed "s#\(.*\)/[^/]*/[^/]*#\1#g"`
	AUDITHOME="$DIRNAME"
}

UsageMsg()
{
   echo "Usage: $THISSCRIPT DBpassword PortNumber"
   echo "	DBpassword is the database password (in clear) for PV_COLL user. Default is PV"
   echo "	PortNumber is the TCP port used by the current collector. Default is 3002."
   echo " "
   echo "The original dataLoad.env must be sourced before starting this tool"
   exit 1
}


SetupFilePermissions()
{
	echo "Setting file permissions ..."
	cp $NEWPVMHOME/contribs/dialogTest2 $NEWPVMHOME/bin/
	chmod 750 $NEWPVMHOME/bin/*
	chmod 750 $NEWPVMHOME/lib/*
	chmod 750 $AUDITHOME/*.sh
	chmod 750 $AUDITHOME/auditctrl
}

CloneOriginalConfiguration( )
{
#set -x

	echo "Cloning PROVISO configuration ..."
	$NEWPVMHOME/bin/dialogTest2 confDump all -P $COLL_REF_PORT | grep GLOBAL > $NEWPVMHOME/conf/dl.cfg.ref
	$NEWPVMHOME/bin/dialogTest2 confDump -P $COLL_REF_PORT | grep SNMP >> $NEWPVMHOME/conf/dl.cfg.ref

	if [ `wc -l $NEWPVMHOME/conf/dl.cfg.ref | nawk '{print $1}'` -le 30 ]; then
		echo "... Problem getting the configuration from current collector." ;
		echo "Check that the collector is running, and that the port ($COLL_REF_PORT) is correct" ;
		exit 1;
	fi


	NEWCHANNELNUMBER=`grep "SNMP.*TUNING.CHANNELNUMBER" $NEWPVMHOME/conf/dl.cfg.ref | nawk -F '=' '{print $2}'`
	NEWCOLLECTORNUMBER=`grep "SNMP.*TUNING.COLLECTORNUMBER" $NEWPVMHOME/conf/dl.cfg.ref | nawk -F '=' '{print $2}'`
	DB_ENVIRONMENT=`grep "DB_ENVIRONMENT=" $NEWPVMHOME/conf/dl.cfg.ref | tail -1 | nawk -F '=' '{print $2}'`
	DB_USERNAME=`grep "DB_USERNAME=" $NEWPVMHOME/conf/dl.cfg.ref | tail -1 | nawk -F '=' '{print $2}'`
	DB_PASSWORD=`grep "DB_PASSWORD=" $NEWPVMHOME/conf/dl.cfg.ref | tail -1 | nawk -F '=' '{print $2}'`

	cat $NEWPVMHOME/conf/dl.cfg.ref |
	sed	"s/^SNMP./AUDIT./g" |
	sed	"s/WATCHMGR.ACTIVATEWATCHMGR=.*/WATCHMGR.ACTIVATEWATCHMGR=0/g" |
	sed 	"s@ROOT_DIRECTORY=.*@ROOT_DIRECTORY=$NEWPVMHOME@g" |
	sed 	"s@DATAMANAGER.DUMPDIR=.*@DATAMANAGER.DUMPDIR=$NEWPVMHOME@g" |
	sed 	"s/LOGMANAGER.FILEPREFIX=.*/LOGMANAGER.FILEPREFIX=AUDIT/g" |
	sed 	"s/HA.ACTIVATE=.*/HA.ACTIVATE=False/g" |
	sed 	"s/TUNING.SERVICEPORT=.*/TUNING.SERVICEPORT=4002/g" |
	grep -v "DATAMANAGER.OUTPUTDIR" |
	grep -v "DATAMANAGER.STATEDIR" |
	grep -v "DATAMANAGER.TMPDIR" |
	grep -v "CONF_DIRECTORY" |
	grep -v "LOGMANAGER.LOGDIR" |
	grep -v "SNMP.MIBFILESPATH" |
	grep -v "TUNING.CONFIGURATIONFILE" |
	grep -v "WATCHMGR.COMMANDLINE" > $NEWPVMHOME/conf/dl.cfg
}

CreateAuditEnv( )
{
#set -x

	echo "Creating Audit environment files ..."
	
	cat <<_CONF_ >$AUDITHOME/audit.env
	
#!/bin/ksh
#
#	This is the runtime configuration for the audit tool
#	 COLL_REF_xxx refers to the 4.2.x, 4.3.x , 4.4 or 4.4.1 collector
#	 COLL_NEW_xxx refers to the audit collector (the current build)
#
COLL_REF_HOST=localhost
COLL_REF_PORT=$COLL_REF_PORT
export COLL_REF_HOST COLL_REF_PORT
#
#
COLL_NEW_HOST=localhost
COLL_NEW_PORT=4002
export COLL_NEW_HOST COLL_NEW_PORT
#
#       This is the path to the database
#
DB_TNSENTRY=$DB_ENVIRONMENT
DB_USER=$DB_USERNAME
DB_PASSWD=$DATABASE_PASSWORD
export DB_TNSENTRY DB_USER DB_PASSWD

NEWCHANNELNUMBER=$NEWCHANNELNUMBER
NEWCOLLECTORNUMBER=$NEWCOLLECTORNUMBER
export NEWCHANNELNUMBER NEWCOLLECTORNUMBER

NEWPVMHOME=$NEWPVMHOME
export NEWPVMHOME

LD_LIBRARY_PATH=$NEWPVMHOME/lib:$LD_LIBRARY_PATH
export LD_LIBRARY_PATH

ulimit -Sn 1024

_CONF_

}

##########################################
#
# Main
#
##########################################
CheckEnv
CheckOptions $*

# Setup correct permissions on files
SetupFilePermissions

# Clone configuration from reference collector
#	+adjustments, to dl.cfg and dataLoad.env
CloneOriginalConfiguration

# update local audit.env
CreateAuditEnv

# Start the SQL dump, for the audit
. $AUDITHOME/audit.env

if [ ! -d sql.tools ]; then
	mkdir sql.tools;
	fi
	
echo "Pre-selecting metrics and resources in the database ..."
$AUDITHOME/auditExtractDbConf.sh


# Display short documentation

echo " Audit is now installed "
echo " "
echo " `wc -l $AUDITHOME/allCollMetrics.txt | nawk '{print $1}'` metrics have been pre-selected for the collection audit "
echo "   against `wc -l $AUDITHOME/allCollSubElmts.txt | nawk '{print $1}'` subelements.(allCollMetrics.txt & allCollSubElmts.txt)"
echo " `wc -l $AUDITHOME/allDiscMetrics.txt | nawk '{print $1}'` metrics have been pre-selected for the discovery audit "
echo "   against `cat $AUDITHOME/allDiscElmts.txt | nawk -F '|' '{print $1}' | sort -u | wc -l  | nawk '{print $1}'` unique IPs.(allDiscMetrics.txt & allDiscElmts.txt)"
echo " "
echo " You may start the audit collector with './auditctrl start'"
echo " (use './auditctrl status' to check, or './auditctrl stop' to stop the audit collector)"
echo " "
echo " Once the audit collector is running, and you've inspected the content of the metric and resource files, you may"
echo " start the 'Discovery' audit, followed by the 'Collection' audit. "
echo " Caution, it is not recommended to have both running simultaneously !"
echo " "
echo " ./testDiscoveries.sh"
echo " ./testCollections.sh"
echo " "



