#!/bin/bash
#set -x

THISSCRIPT=`basename $0`
DIRNAME=`dirname $0`
. $DIRNAME/audit.env

testFileDate=$DIRNAME/`date '+resDisc_%m.%d-%H.%M/'`

mkdir $testFileDate

FORMGET=$NEWPVMHOME/bin/formGet
DIALOGTEST2=$NEWPVMHOME/bin/dialogTest2

logFileRef=`echo "${testFileDate}log_Cref_${COLL_REF_HOST}.${COLL_REF_PORT}.txt"`
logFileNew=`echo "${testFileDate}log_Cnew_${COLL_NEW_HOST}.${COLL_NEW_PORT}.txt"`

diffFile=`echo "${testFileDate}diffSummary.txt"`

failFileRef=`echo "${testFileDate}fail_Cref_${COLL_REF_HOST}.${COLL_REF_PORT}.txt"`
failFileNew=`echo "${testFileDate}fail_Cnew_${COLL_NEW_HOST}.${COLL_NEW_PORT}.txt"`

tmpFileRef=`echo "${testFileDate}${COLL_REF_HOST}.${COLL_REF_PORT}.txt.tmp"`
tmpFileNew=`echo "${testFileDate}${COLL_NEW_HOST}.${COLL_NEW_PORT}.txt.tmp"`

allDiscElmts=$DIRNAME/allDiscElmts.txt
allDiscMetrics=$DIRNAME/allDiscMetrics.txt

allCollSubElmts=$DIRNAME/allCollSubElmts.txt
allCollMetrics=$DIRNAME/allCollMetrics.txt

echo	"LogFiles " | tee -a $diffFile
echo	"	$logFileRef" | tee -a $diffFile
echo	"	$logFileNew" | tee -a $diffFile
echo  	" " | tee -a $diffFile
echo	"tmpFiles " | tee -a $diffFile
echo	"	$tmpFileRef" | tee -a $diffFile
echo	"	$tmpFileNew" | tee -a $diffFile
echo  	" " | tee -a $diffFile
echo	"failFiles " | tee -a $diffFile
echo	"	$failFileRef" | tee -a $diffFile
echo	"	$failFileNew" | tee -a $diffFile
echo  	" " | tee -a $diffFile
echo	"diffFile " | tee -a $diffFile
echo	"	$diffFile" | tee -a $diffFile
echo  	" " | tee -a $diffFile
echo  	" " | tee -a $diffFile

VERSIONREF=`$DIALOGTEST2 version -S ${COLL_REF_HOST} -P ${COLL_REF_PORT} | grep Version`
VERSIONNEW=`$DIALOGTEST2 version -S ${COLL_NEW_HOST} -P ${COLL_NEW_PORT} | grep Version`

echo	" Collector Ref is ${COLL_REF_HOST}.${COLL_REF_PORT}" | tee -a $diffFile
echo  	" $VERSIONREF" | tee -a $diffFile
echo	" Collector New is ${COLL_NEW_HOST}.${COLL_NEW_PORT}" | tee -a $diffFile
echo 	" $VERSIONNEW" | tee -a $diffFile

if [ ! "$VERSIONREF" ]; then
	echo "Error: The reference collector is not running, or the port is invalid" ;
	exit 1;
fi

if [ ! "$VERSIONNEW" ]; then
	echo "Error: The audit collector is not running, or the port is invalid" ;
	exit 1;
fi

echo 	" " | tee -a $diffFile
echo 	" " | tee -a $diffFile

cat "${allDiscElmts}" | nawk -F "|" '{print $1}' | sort -u |
while read ip
do	
	# check that the IP can be contacted by both collectors
	#	if not put a BIG warning
	#
	rm -f ${tmpFileRef}
	resA=`$FORMGET $ip "sysName.0" -i "Null<null>" -S $COLL_REF_HOST -P $COLL_REF_PORT -dt string | grep "${ip}:.*:" | sed "s/:/ /g" | nawk '{print $3}'`
	resB=`$FORMGET $ip "sysName.0" -i "Null<null>" -S $COLL_NEW_HOST -P $COLL_NEW_PORT -dt string | grep "${ip}:.*:" | sed "s/:/ /g" | nawk '{print $3}'`
	
	if [ "${resA}" == "${resB}" -a -n "${resB}" -a -n "${resA}" ] ; then

	while IFS='|' read id fname junk
	do
		message=`echo "Form '$fname' (id=$id) on ip=$ip"`

		testTime=`date '+%H.%M.%S'`
		echo " "
		echo "* Testing discovery $message @ ${testTime}" | tee ${tmpFileRef} | tee ${tmpFileNew}
		echo "  $FORMGET $ip -fid $id -i '<*><*>'"

		$FORMGET $ip -fid $id -i "<*><*>" -S $COLL_REF_HOST -P $COLL_REF_PORT >> ${tmpFileRef}
#		grep -v "Failure:" $tmpFileRef | grep -v "!ERROR!" | grep -v "Timeout, the daemo" | grep "${ip}:.*:" | sort > ${tmpFileRef}.sorted
		grep -v "Failure:" $tmpFileRef | grep -v "!ERROR!" | grep -v "Timeout, the daemo" | grep -v "^[ \t]*$" | sort > ${tmpFileRef}.sorted
		echo "Cref: returned `wc -l ${tmpFileRef}.sorted | nawk '{print $1}'` lines(s)"
		cat ${tmpFileRef} >> $logFileRef

		$FORMGET $ip -fid $id -i "<*><*>" -S $COLL_NEW_HOST -P $COLL_NEW_PORT >> ${tmpFileNew}
#		grep -v "Failure:" $tmpFileNew | grep -v "!ERROR!" | grep -v "Timeout, the daemo" | grep "${ip}:.*:" | sort  > ${tmpFileNew}.sorted
		grep -v "Failure:" $tmpFileNew | grep -v "!ERROR!" | grep -v "Timeout, the daemo" | grep -v "^[ \t]*$" | sort  > ${tmpFileNew}.sorted
		echo "Cnew: returned `wc -l ${tmpFileNew}.sorted | nawk '{print $1}'` lines(s)"
		cat ${tmpFileNew} >> $logFileNew
		
		diff ${tmpFileRef}.sorted ${tmpFileNew}.sorted | sed "s/^</Cref:/" | sed "s/^>/Cnew:/" > ${diffFile}.tmp
		if [ -s ${diffFile}.tmp ] ; then

			fullDiffFile=`echo "${testFileDate}diff_${fname}_${ip}.txt"`
			echo "**** ERROR, Testing discovery $message @ ${testTime}" | tee -a ${diffFile} | tee -a "${fullDiffFile}"
			echo "  $FORMGET $ip -fid $id -i '<*><*>' " | tee -a ${diffFile} | tee -a "${fullDiffFile}"
			echo "  Cref: returned `wc -l ${tmpFileRef}.sorted | nawk '{print $1}'` object(s)" | tee -a ${diffFile} | tee -a "${fullDiffFile}"
			echo "  Cnew: returned `wc -l ${tmpFileNew}.sorted | nawk '{print $1}'` object(s)" | tee -a ${diffFile} | tee -a "${fullDiffFile}"
			echo " " | tee -a ${diffFile} | tee -a "${fullDiffFile}"

			cat ${diffFile}.tmp | tee -a "${fullDiffFile}"
			echo " " | tee -a ${diffFile} | tee -a "${fullDiffFile}"
			echo " Debug Trace with Cref:" | tee -a "${fullDiffFile}"
			$FORMGET $ip -fid $id -i "<*><*>" -S $COLL_REF_HOST -P $COLL_REF_PORT -TL 3 >> "${fullDiffFile}"
			
			echo " " | tee -a "${fullDiffFile}"
			echo " Debug Trace with Cnew:" | tee -a "${fullDiffFile}"
			echo " Full debug under task ID # `$DIALOGTEST2 debug 6.next -S $COLL_NEW_HOST -P $COLL_NEW_PORT | tail -1 | nawk '{print $3}'`" | tee -a "${fullDiffFile}"
			$FORMGET $ip -fid $id -i "<*><*>" -S $COLL_NEW_HOST -P $COLL_NEW_PORT -TL 3 >> "${fullDiffFile}"
		fi
	
		grep "Failure:" $tmpFileRef | sed "s/Failure/${message} Failure/" >> $failFileRef
		grep "Failure:" $tmpFileNew | sed "s/Failure/${message} Failure/" >> $failFileNew

		rm -f ${tmpFileRef}.sorted
		rm -f ${tmpFileNew}.sorted
		rm -f ${diffFile}.tmp
		rm -f ${tmpFileRef}
		rm -f ${tmpFileNew}
	done < "${allDiscMetrics}"
	else
		echo " "
		echo "**** WARNING, Skipping discovery on ip $ip " | tee -a $failFileRef | tee -a $failFileNew | tee -a ${fullDiffFile}
		echo " " | tee -a $failFileRef | tee -a $failFileNew | tee -a ${fullDiffFile}
	fi
done


