#!/bin/ksh
#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#
# FileName      : activate_saa.ksh
# Author        : tjoh
# Date          : 05/18/2006
# Subject       : Activate support for SAA in 4.4.1
# Exit codes    : 
# Environment   : 
#
# Netcool/Proviso
# Copyright (c) 2006 Micromuse, Inc.  All rights reserved.
#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

#----------------------------------------------------------------------
# command line switches to this script
#
KEY_CLIorasid="-os";             # ORACLE_SID value [if different from the environment]
KEY_CLIorahome="-oh";            # ORACLE_HOME value [if different from the environment]
KEY_CLIoraUser="-ou";            # ORACLE user with administrative privs on DM
KEY_CLIoraUserPass="-oup";       # ORACLE user's password with administrative privs on DM
KEY_CLIusage="-u";               # usage clause

#----------------------------------------------------------------------
# Usage clause
#
usage()
{
  cat <<EOF

Usage: ${0} 

    [${KEY_CLIorasid} <ORACLE_SID>] 
    [${KEY_CLIorahome} <ORACLE_HOME>] 
    [${KEY_CLIoraUser} <ORACLE user with admin privs - (i.e. PV_ADMIN)>] 
    [${KEY_CLIoraUserPass} <ORACLE user's passwd with admin privs>] 
    [${KEY_CLIusage}]

EOF
  exit 1;
}


#----------------------------------------------------------------------
# parse command line arguments
#
while [ "${1}" ]
do
   case "${1}" in

      "${KEY_CLIorasid}")  
         shift
         orasid=${1}
         ;;

      "${KEY_CLIorahome}") 
         shift
         if [ -f "${1}/bin/sqlplus" ]
         then
            orahome=${1}
         else
            echo "${0} error: invalid ORACLE_HOME path"
            usage 
         fi
         ;;

      "${KEY_CLIoraUser}") 
         shift
         oraUser=${1}
         ;;

      "${KEY_CLIoraUserPass}") 
         shift
         oraUserPass=${1}
         ;;

      "${KEY_USAGE}"*) 
         usage
         ;;

      *) echo "${0}: unknown option: ${1}"
         usage
         ;;
   esac
   shift
done

#----------------------------------------------------
# Deal with default environmentaly defined values 
# of script variables. If any of the variables are 
# NOT defined through the CLI switches to this 
# script, use the default or raise an error
#
if [ ! -n "${orasid}" ]
then
   if [ ! -n "${ORACLE_SID}" ]
   then
      usage;
   else
      orasid="${ORACLE_SID}"
   fi
fi

if [ ! -n "${orahome}" ]
then
   if [ ! -n "${ORACLE_HOME}" ]
   then
      usage;
   else
      orahome="${ORACLE_HOME}"
   fi
fi

if [ ! -n "${oraUser}" ]
then
   usage;
fi

if [ ! -n "${oraUserPass}" ]
then
   usage;
fi

ORACLE_HOME=${orahome}
export ORACLE_HOME

LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$ORACLE_HOME/lib
export LD_LIBRARY_PATH

ORACLE_SID=${orasid}
export ORACLE_SID

PATH=$PATH:$ORACLE_HOME/bin
export PATH


#----------------------------------------------------------------------
# Run activation
#
activateSaa()
{

${orahome}/bin/sqlplus -s  <<__SQL__
${oraUser}/${oraUserPass}@${orasid}

Set Echo Off
Set ServerOutput On Size 1000000

Declare
  iCount  Number;
Begin
  -- Make sure the reporters exist
  Select Count(*)
    Into iCount
    From APP_DESC
   Where Idx_Ind In (7574,7577,7643,8052);
  If iCount != 4 Then
    Pvm_Error.Raise_Error( -20022, 'SAA Reporters were not found' );
  End If;

  -- Update the reporters
  Update APP_DESC 
     Set Str_Url = 'DVJitterProbeConfiguration.html'
   Where Idx_Ind = 7574;
  Update APP_DESC 
     Set Str_Url = 'DVEchoProbeConfiguration.html'
   Where Idx_Ind = 7577;
  Update APP_DESC 
     Set Str_Url = 'DVProbeManagement.html'
   Where Idx_Ind = 7643;
  Update APP_DESC 
     Set Str_Url = 'DVProbeConfiguration_File.html'
   Where Idx_Ind = 8052;
  Commit;

  -- Verify reporters
  For recCheck In ( Select Idx_Ind, Str_Url
                      From APP_DESC
                     Where Idx_Ind In (7574,7577,7643,8052) )
  Loop
    If recCheck.Idx_Ind = 7574                               And
       recCheck.Str_Url != 'DVJitterProbeConfiguration.html' Then
      Pvm_Error.Raise_Error( -20022, 'Activation was not successful' );
    End If;
    If recCheck.Idx_Ind = 7577                               And
       recCheck.Str_Url != 'DVEchoProbeConfiguration.html' Then
      Pvm_Error.Raise_Error( -20022, 'Activation was not successful' );
    End If;
    If recCheck.Idx_Ind = 7643                               And
       recCheck.Str_Url != 'DVProbeManagement.html' Then
      Pvm_Error.Raise_Error( -20022, 'Activation was not successful' );
    End If;
    If recCheck.Idx_Ind = 8052                               And
       recCheck.Str_Url != 'DVProbeConfiguration_File.html' Then
      Pvm_Error.Raise_Error( -20022, 'Activation was not successful' );
    End If;
  End Loop;

  -- Notify success
  Dbms_Output.Put_Line( '----------------------------------------------' );
  Dbms_Output.Put_Line( '-     SAA support activation successful      -' );
  Dbms_Output.Put_Line( '----------------------------------------------' );
Exception
  When OTHERS Then 
    -- Notify failure
    Dbms_Output.Put_Line( '----------------------------------------------' );
    Dbms_Output.Put_Line( '-   Error - Unable to activate SAA support   -' );
    Dbms_Output.Put_Line( '----------------------------------------------' );
    Raise;
End;
/

__SQL__

}

#----------------------------------------------------------------------
# Main body of script - Log into SQL*Plus and run the activation

# Activate SAA
activateSaa;
