#
# 4.4.1.4 patch install script
#

LOG_FILE=patch4414.log

#############################################
# Functions
#############################################

CheckEnvironment()
{

BASENAME=`basename $0`
DIRNAME=`dirname $0`
UPGRADE_PATH=$DIRNAME

CURRENT_USER=`id | awk -F"(" '{print $2}' | awk -F")" '{print $1}'`
if [ ! "$CURRENT_USER" = "root" ]; then
   echo "\nError : Must be run as root!"
   UsageMsg
fi

TYPE=`echo $TYPE | tr '[A-Z]' '[a-z]'`
if [ "$TYPE" = "datamart" ] || [ "$TYPE" = "dataload" ]; then   
   LOG_PATH=$DATAHOME/log/$LOG_FILE
   FILE_PVM_OWNER=$DATAHOME/version 
   if [ -f "$FILE_PVM_OWNER" ]; then
      PVM_USER=`ls -o $FILE_PVM_OWNER | awk '{print $3}'`
      PVM_GROUP=`ls -g $FILE_PVM_OWNER | awk '{print $3}'`
   else
      echo "\nError : Invalid Proviso directory, can't find $FILE_PVM_OWNER"
      UsageMsg
   fi
   if    [ -z "$DATAHOME" ]; then
      UsageMsg
   elif  [ ! -d "$DATAHOME" ]; then
      echo "\nError : $TYPE home $DATAHOME does not exist!"
      UsageMsg
   fi
   if [ "$TYPE" = "datamart" ]; then
      if [ ! -f "$DATAHOME/dataMart.env" ]; then
         echo "\nError : Can't find $DATAHOME/dataMart.env, not a valid datamart directory!"
         if [ "$FORCE" = "no" ]; then
            echo "Enter the correct directory path, or run with -f switch to override this error."
            UsageMsg
         else
            echo "Overriding with -f switch.\n"
         fi
      fi
   elif [ "$TYPE" = "dataload" ]; then
      if [ ! -f "$DATAHOME/dataLoad.env" ] && [ "$FORCE" = "no" ]; then
         echo "\nError : Can't find $DATAHOME/dataLoad.env, not a valid dataload
 directory!"
         UsageMsg
      fi
   fi      
else
   echo "\nError : Invalid type $TYPE, valid types are datamart or dataload "
   UsageMsg
fi

}

GetSNMPVersion()
{
#   if [ ! -x $DATAHOME/bin/pvmd ]; then
#      ErrorMsg "$DATAHOME/bin/pvmd not found or not executable!"
#   fi
   . $DATAHOME/dataLoad.env
   VERSION_INFO=`$DATAHOME/bin/pvmd -v | xargs`
   PVMD_VERSION=`echo $VERSION_INFO | sed -e "s/.*Comment: PV //g" | sed -e "s/ SNMP_DL.*//g"`
   OS_VERSION=`echo $VERSION_INFO | awk '{print $2}'`
#   ORACLE_VERSION=`echo $OS_VERSION | sed -e "s/SOL.ORA//g"`
#   ORACLE_VERSION=`/bin/ldd $DATAHOME/lib/libtclOracle.so  | grep libclntsh.so | awk '{print $1}' | sed -e "s/libclntsh.so.//g" | sed -e "s/.0//g"` 
ORACLE_VERSION=8
   LogMsg "pvmd $PVMD_VERSION has support for Oracle $ORACLE_VERSION installed"
}

GetDMOracleVersion()
{
   ORACLE_VERSION=`/bin/ldd $DATAHOME/lib/libtclOracle.so  | grep libclntsh.so | awk '{print $1}' | sed -e "s/libclntsh.so.//g" | sed -e "s/.0//g"`
   LogMsg "$DATAHOME/lib/libtclOracle.so has support for Oracle $ORACLE_VERSION installed"
} 

UpgradeDLFiles()
{
   #set -x
  ORACLE_VERSION=`/bin/ldd $DATAHOME/lib/libpvmd.so | grep libclntsh.so | awk '{print $1}' | sed -e "s/libclntsh.so.//g" | sed -e "s/.0//g"`  

   INSTALL_PATH="$UPGRADE_PATH/DL4.4.1.4R2E1-patch/DL-4.4.1.4R2E1-ora$ORACLE_VERSION"
   if [ ! -d "$INSTALL_PATH" ]; then
      ErrorMsg "Install directory $INSTALL_PATH does not exist!"
   fi
   UPGRADESCRIPT="$INSTALL_PATH/contribs/dlPatch.sh"
   if [ ! -x "$UPGRADESCRIPT" ]; then
      ErrorMsg "Missing, or non executable $UPGRADESCRIPT file!"
   fi
	
   PATCH_DATE=`date '+%y%m%d_%H%M'`
	
   echo "$UPGRADESCRIPT prepare $PATCH_DATE.441FP001 $INSTALL_PATH $DATAHOME"	
   su $PVM_USER -c "/bin/sh -c \"$UPGRADESCRIPT prepare $PATCH_DATE.441FP001 $INSTALL_PATH $DATAHOME\""	| tee -a $LOG_PATH
   if [ ! $? -eq 0 ]; then
	ErrorMsg "There has been a problem applying the patch (Your system has NOT been altered)."
	return 1
   fi

  if [ "$LOGONLY" = "no" ]; then
	
   echo "$UPGRADESCRIPT install $PATCH_DATE.441FP001 $INSTALL_PATH $DATAHOME"	

   $UPGRADESCRIPT install $PATCH_DATE.441FP001 $INSTALL_PATH $DATAHOME | tee -a $LOG_PATH	
   if [ ! $? -eq 0 ]; then
	ErrorMsg "There has been a problem applying the patch. Warning, your system may be in an unstable state !"
	return 1
   fi
  fi 
}

CopyDMFiles()
{
 INSTALL_PATH="$UPGRADE_PATH/DM4.4.1.4-patches/DM4.4.1.4-patch-ora$ORACLE_VERSION"
   FILE_LIST="pvm.ar tools.ar"

   LogMsg "Installing from $INSTALL_PATH to $DATAHOME/arc"
   LogMsg "Installing files $FILE_LIST"

   for FILE in $FILE_LIST; do
      LogMsg "   Copying $FILE, setting read/write permissions, owner is $PVM_USER"
      if [ "$LOGONLY" = "no" ]; then
         systemcall "cp $INSTALL_PATH/$FILE /tmp"
         systemcall "mv /tmp/$FILE $DATAHOME/arc"
         systemcall "chmod 444 $DATAHOME/arc/$FILE"
         systemcall "chown $PVM_USER:$PVM_GROUP $DATAHOME/arc/$FILE"
      fi
   done

INSTALL_PATH="$UPGRADE_PATH/DM4.4.1.4-patches/DM4.4.1.4-patch-ora$ORACLE_VERSION"
   FILE_LIST="mibbrow mibcomp snmpconf confReload dbRep formGet pvmdctrl qPing snmpGet snmpSet statGet"

   LogMsg "Installing from $INSTALL_PATH to $DATAHOME/bin"
   LogMsg "Installing files $FILE_LIST"

   for FILE in $FILE_LIST; do
      LogMsg "   Copying $FILE, setting read/write permissions, owner is $PVM_USER"
      if [ "$LOGONLY" = "no" ]; then
         systemcall "cp $INSTALL_PATH/$FILE /tmp"
         systemcall "mv /tmp/$FILE $DATAHOME/bin"
         systemcall "chmod 555 $DATAHOME/bin/$FILE"
         systemcall "chown $PVM_USER:$PVM_GROUP $DATAHOME/bin/$FILE"
      fi
        systemcall "cp $INSTALL_PATH/version $DATAHOME/."

   done
  systemcall "chown root $DATAHOME/bin/qPing"
  systemcall "chmod 6554 $DATAHOME/bin/qPing"

#if [ ! -f "$DATAHOME/dataLoad.env" ]

if [ ! -f "$DATAHOME/bin/create_modify_aggset_def.pretimezone" ]; then
systemcall "mv $DATAHOME/bin/create_modify_aggset_def $DATAHOME/bin/create_modify_aggset_def.pretimezone"
fi

if [ ! -f "$DATAHOME/bin/pvm4337.pretimezone" ]; then
systemcall "mv $DATAHOME/bin/pvm4337 $DATAHOME/bin/pvm4337.pretimezone"
fi

if [ ! -f "$DATAHOME/classes/DSTConfig.jar.pretimezone" ]; then
systemcall "mv $DATAHOME/classes/DSTConfig.jar $DATAHOME/classes/DSTConfig.jar.pretimezone"
fi
systemcall "chmod -f 755 $DATAHOME/bin/create_modify_aggset_def"
systemcall "chmod -f 755 $DATAHOME/bin/pvm4337"
systemcall "cp $INSTALL_PATH/create_modify_aggset_def $DATAHOME/bin"
systemcall "cp $INSTALL_PATH/pvm4337 $DATAHOME/bin"
systemcall "chmod -f 555 $DATAHOME/bin/pvm4337"
systemcall "chmod -f 555 $DATAHOME/bin/create_modify_aggset_def"
systemcall "chown $PVM_USER:$PVM_GROUP $DATAHOME/bin/pvm4337"
systemcall "chown $PVM_USER:$PVM_GROUP $DATAHOME/bin/create_modify_aggset_def"

   INSTALL_PATH="$UPGRADE_PATH/DM4.4.1.4-R2E1-RE-patch/DM4.4.1.4-ora$ORACLE_VERSION"
#   FILE_LIST=" "
   FILE_LIST="pvgui.im requestedit visual"

   LogMsg "Installing from $INSTALL_PATH to $DATAHOME/bin"
   LogMsg "Installing files $FILE_LIST"

   for FILE in $FILE_LIST; do
      LogMsg "   Copying $FILE, setting execute permissions, owner is $PVM_USER"
      if [ "$LOGONLY" = "no" ]; then
         systemcall "cp $INSTALL_PATH/$FILE /tmp"
         systemcall "mv /tmp/$FILE $DATAHOME/bin"
         systemcall "chmod 755 $DATAHOME/bin/$FILE"
         systemcall "chown $PVM_USER:$PVM_GROUP $DATAHOME/bin/$FILE"
      fi
   done

INSTALL_PATH="$UPGRADE_PATH/DM4.4.1.4-patches/DM4.4.1.4-patch-ora$ORACLE_VERSION"
   FILE_LIST="dbspaceV3.conf"

   LogMsg "Installing from $INSTALL_PATH to $DATAHOME/conf"
   LogMsg "Installing files $FILE_LIST"

   for FILE in $FILE_LIST; do
      LogMsg "   Copying $FILE, setting read/write permissions, owner is $PVM_USER"
      if [ "$LOGONLY" = "no" ]; then
         systemcall "cp $INSTALL_PATH/$FILE /tmp"
         systemcall "mv /tmp/$FILE $DATAHOME/conf"
         systemcall "chmod 444 $DATAHOME/conf/$FILE"
         systemcall "chown $PVM_USER:$PVM_GROUP $DATAHOME/conf/$FILE"
      fi
   done

INSTALL_PATH="$UPGRADE_PATH/DM4.4.1.4-patches/DM4.4.1.4-patch-ora$ORACLE_VERSION"
   FILE_LIST="snmp.res resmgr.res reseditNG.res"

   LogMsg "Installing from $INSTALL_PATH to $DATAHOME/res/C"
   LogMsg "Installing files $FILE_LIST"

   for FILE in $FILE_LIST; do
      LogMsg "   Copying $FILE, setting read/write permissions, owner is $PVM_USER"
      if [ "$LOGONLY" = "no" ]; then
         systemcall "cp $INSTALL_PATH/$FILE /tmp"
         systemcall "mv /tmp/$FILE $DATAHOME/res/C"
         systemcall "chmod 444 $DATAHOME/res/C/$FILE"
         systemcall "chown $PVM_USER:$PVM_GROUP $DATAHOME/res/C/$FILE"
      fi
   done


   INSTALL_PATH="$UPGRADE_PATH/DM4.4.1.4-class-patch/DM4.4.1.4-ora$ORACLE_VERSION"
   FILE_LIST=" "

   LogMsg "Installing from $INSTALL_PATH to $DATAHOME/classes"
   LogMsg "Installing files $FILE_LIST"

   for FILE in $FILE_LIST; do
      LogMsg "   Copying $FILE, setting execute permissions, owner is $PVM_USER"
      if [ "$LOGONLY" = "no" ]; then
         systemcall "cp $INSTALL_PATH/$FILE /tmp"
         systemcall "mv /tmp/$FILE $DATAHOME/classes"
         systemcall "chmod 755 $DATAHOME/classes/$FILE"
         systemcall "chown $PVM_USER:$PVM_GROUP $DATAHOME/classes/$FILE"
      fi
   done

}

systemcall()
{
   eval ${1}
   return=$?
   if [ ! "$return" = 0 ]; then
     LogMsg "Failed with shell error code $return, terminating."
     exit $return
   fi
}

CreateLog()
{
   if [ ! -f "$LOG_PATH" ]
   then
      touch $LOG_PATH >/dev/null 2>&1
   fi 
}

LogMsg()
{
   echo "`date`: $1" | tee -a $LOG_PATH
}

ErrorMsg()
{
   LogMsg "Error : $1"
   LogMsg "Patch 4.4.1.4 terminated"
   exit 1
}

UsageMsg()
{  
   echo
   echo "Usage: $BASENAME -t ( dataload | datamart ) -h < home directory > [ -dlf ]"
   echo
   echo "   -t   type             type datamart - mandatory"
   echo "   -h   home directory   home directory for datamart - mandatory"
   echo "   -d   debug            print debugging information"
   echo "   -l   log only         log what would be done only, do not upgrade"
   echo "   -f   force            force skip dataMart.env check (use only if needed)"
   echo

   exit 2
}

#############################################
# Main
#############################################

LOGONLY=no
FORCE=no
PATH=$PATH:/usr/bin

#GetOptions
while getopts dflh:t: OPTION
do
   case ${OPTION} in
       d) set -x;;
       f) FORCE=yes;;
       l) LOGONLY=yes;;
       h) DATAHOME=${OPTARG};;
       t) TYPE=${OPTARG};;
       *) UsageMsg;;
   esac
done

CheckEnvironment
CreateLog
LogMsg "**************************************************************"
LogMsg "                     $TYPE patch 4.4.1.4"
LogMsg "**************************************************************"
LogMsg "START Upgrade $TYPE in $DATAHOME - environment OK"

if   [ "$TYPE" = "dataload" ]; then
   UpgradeDLFiles
elif [ "$TYPE" = "datamart" ]; then
   GetDMOracleVersion
#   CopyDLFiles
   CopyDMFiles
fi

LogMsg "FINISHED Patch 4.4.1.4 $TYPE succeeded\n\n"
echo "Patch 4.4.1.4 logged in $LOG_PATH\n"

######################################################################
# ChangeLog
#
# 05.31.08  4414 DM update
# 04.23.08      4.4.1.4 patches
# 12.04.2007    4.4.1.3 1.8.8.1 patches
# 10.29.2007    4.4.1.3 - 4.4.1.2 and 4.4.1.3 added to sparkler
# 05.01.2007    4.4.1.1 - Modified for DL patch script updates
# 04.30.2007    4.4.1.1 - Modified for DM 4.4.1.1- MR1 updates plus TF patches
